@@ -19,7 +19,14 @@ class ApplicationsUtils:
             environment_variable_id = found_environment_variable['id']
             self.applications_endpoint.update_env_var(environment_variable_id, value, is_secure)
 
-    def delete_all_environment_variables(self, app_id):
+    def delete_all_environment_variables(self):
         env_vars = self.applications_endpoint.get_all_environment_variables().json()
         for env_var in env_vars:
-            self.applications_endpoint.delete_env_var(app_id, env_var['id'])
\ No newline at end of file
+            self.applications_endpoint.delete_env_var(self.applications_endpoint.app_id, env_var['id'])
+
+    def get_environment_variable(self, key, group):
+        env_vars = self.applications_endpoint.get_all_environment_variables().json()
+        for env_var in env_vars:
+            if env_var['id'] == key and env_var['group'] == group:
+                return env_var
+        return None
